@@ -37,6 +37,7 @@ from foundry import (
     get_latest_version_name,
     github_link,
     icon,
+    main_window_flags_path,
     open_url,
     releases_link,
 )
@@ -79,29 +80,12 @@ ROM_FILE_FILTER = "ROM files (*.nes *.rom);;All files (*)"
 M3L_FILE_FILTER = "M3L files (*.m3l);;All files (*)"
 IMG_FILE_FILTER = "Screenshots (*.png);;All files (*)"
 
-ID_RELOAD_LEVEL = 303
+with open(main_window_flags_path, "r") as data:
+    main_window_flags = json.loads(data.read())
+del data
 
-ID_GRID_LINES = 501
-ID_TRANSPARENCY = 508
-ID_JUMPS = 509
-ID_MARIO = 510
-ID_RESIZE_TYPE = 511
-ID_JUMP_OBJECTS = 512
-ID_ITEM_BLOCKS = 513
-ID_INVISIBLE_ITEMS = 514
-ID_AUTOSCROLL = 515
-
-CHECKABLE_MENU_ITEMS = [
-    ID_TRANSPARENCY,
-    ID_GRID_LINES,
-    ID_JUMPS,
-    ID_MARIO,
-    ID_RESIZE_TYPE,
-    ID_JUMP_OBJECTS,
-    ID_ITEM_BLOCKS,
-    ID_INVISIBLE_ITEMS,
-    ID_AUTOSCROLL,
-]
+CHECKABLE_MENU_ITEMS = [flag["id"] for flag in main_window_flags["menu"]["view"].values()]
+CHECKABLE_MENU = {flag["id"]: flag for flag in main_window_flags["menu"]["view"].values()}
 
 ID_PROP = "ID"
 
@@ -132,18 +116,9 @@ class MainWindow(QMainWindow):
         self.save_rom_action.triggered.connect(self.on_save_rom)
         self.save_rom_as_action = file_menu.addAction("&Save ROM as ...")
         self.save_rom_as_action.triggered.connect(self.on_save_rom_as)
-        """
-        file_menu.AppendSeparator()
-        """
         self.save_m3l_action = file_menu.addAction("&Save M3L")
         self.save_m3l_action.triggered.connect(self.on_save_m3l)
-        """
-        file_menu.Append(ID_SAVE_LEVEL_TO, "&Save Level to", "")
-        file_menu.AppendSeparator()
-        file_menu.Append(ID_APPLY_IPS_PATCH, "&Apply IPS Patch", "")
-        file_menu.AppendSeparator()
-        file_menu.Append(ID_ROM_PRESET, "&ROM Preset", "")
-        """
+
         file_menu.addSeparator()
         settings_action = file_menu.addAction("&Settings")
         settings_action.triggered.connect(self._on_show_settings)
@@ -153,19 +128,6 @@ class MainWindow(QMainWindow):
 
         self.menuBar().addMenu(file_menu)
 
-        """
-        edit_menu = wx.Menu()
-
-        edit_menu.Append(ID_EDIT_LEVEL, "&Edit Level", "")
-        edit_menu.Append(ID_EDIT_OBJ_DEFS, "&Edit Object Definitions", "")
-        edit_menu.Append(ID_EDIT_PALETTE, "&Edit Palette", "")
-        edit_menu.Append(ID_EDIT_GRAPHICS, "&Edit Graphics", "")
-        edit_menu.Append(ID_EDIT_MISC, "&Edit Miscellaneous", "")
-        edit_menu.AppendSeparator()
-        edit_menu.Append(ID_FREE_FORM_MODE, "&Free form Mode", "")
-        edit_menu.Append(ID_LIMIT_SIZE, "&Limit Size", "")
-        """
-
         self.level_menu = QMenu("Level")
 
         self.select_level_action = self.level_menu.addAction("&Select Level")
@@ -196,80 +158,21 @@ class MainWindow(QMainWindow):
         self.view_menu = QMenu("View")
         self.view_menu.triggered.connect(self.on_menu)
 
-        action = self.view_menu.addAction("Mario")
-        action.setProperty(ID_PROP, ID_MARIO)
-        action.setCheckable(True)
-        action.setChecked(SETTINGS["draw_mario"])
-
-        action = self.view_menu.addAction("&Jumps on objects")
-        action.setProperty(ID_PROP, ID_JUMP_OBJECTS)
-        action.setCheckable(True)
-        action.setChecked(SETTINGS["draw_jump_on_objects"])
-
-        action = self.view_menu.addAction("Items in blocks")
-        action.setProperty(ID_PROP, ID_ITEM_BLOCKS)
-        action.setCheckable(True)
-        action.setChecked(SETTINGS["draw_items_in_blocks"])
-
-        action = self.view_menu.addAction("Invisible items")
-        action.setProperty(ID_PROP, ID_INVISIBLE_ITEMS)
-        action.setCheckable(True)
-        action.setChecked(SETTINGS["draw_invisible_items"])
-
-        action = self.view_menu.addAction("Autoscroll Path")
-        action.setProperty(ID_PROP, ID_AUTOSCROLL)
-        action.setCheckable(True)
-        action.setChecked(SETTINGS["draw_autoscroll"])
-
-        self.view_menu.addSeparator()
-
-        action = self.view_menu.addAction("Jump Zones")
-        action.setProperty(ID_PROP, ID_JUMPS)
-        action.setCheckable(True)
-        action.setChecked(SETTINGS["draw_jumps"])
-
-        action = self.view_menu.addAction("&Grid lines")
-        action.setProperty(ID_PROP, ID_GRID_LINES)
-        action.setCheckable(True)
-        action.setChecked(SETTINGS["draw_grid"])
-
-        action = self.view_menu.addAction("Resize Type")
-        action.setProperty(ID_PROP, ID_RESIZE_TYPE)
-        action.setCheckable(True)
-        action.setChecked(SETTINGS["draw_expansion"])
-
-        self.view_menu.addSeparator()
-
-        action = self.view_menu.addAction("&Block Transparency")
-        action.setProperty(ID_PROP, ID_TRANSPARENCY)
-        action.setCheckable(True)
-        action.setChecked(SETTINGS["block_transparency"])
+        for flag in CHECKABLE_MENU.values():
+            action: QAction = self.view_menu.addAction(flag["display_name"])
+            action.setProperty(ID_PROP, flag["id"])
+            action.setCheckable(True)
+            action.setChecked(SETTINGS[flag["name"]])
+            if flag.get("separator", False):
+                self.view_menu.addSeparator()
 
         self.view_menu.addSeparator()
         self.view_menu.addAction("&Save Screenshot of Level").triggered.connect(self.on_screenshot)
-        """
-        self.view_menu.Append(ID_BACKGROUND_FLOOR, "&Background & Floor", "")
-        self.view_menu.Append(ID_TOOLBAR, "&Toolbar", "")
-        self.view_menu.AppendSeparator()
-        self.view_menu.Append(ID_ZOOM, "&Zoom", "")
-        self.view_menu.AppendSeparator()
-        self.view_menu.Append(ID_USE_ROM_GRAPHICS, "&Use ROM Graphics", "")
-        self.view_menu.Append(ID_PALETTE, "&Palette", "")
-        self.view_menu.AppendSeparator()
-        self.view_menu.Append(ID_MORE, "&More", "")
-        """
 
         self.menuBar().addMenu(self.view_menu)
 
         help_menu = QMenu("Help")
-        """
-        help_menu.Append(ID_ENEMY_COMPATIBILITY, "&Enemy Compatibility", "")
-        help_menu.Append(ID_TROUBLESHOOTING, "&Troubleshooting", "")
-        help_menu.AppendSeparator()
-        help_menu.Append(ID_PROGRAM_WEBSITE, "&Program Website", "")
-        help_menu.Append(ID_MAKE_A_DONATION, "&Make a Donation", "")
-        help_menu.AppendSeparator()
-        """
+
         update_action = help_menu.addAction("Check for updates")
         update_action.triggered.connect(self.on_check_for_update)
 
@@ -646,6 +549,7 @@ class MainWindow(QMainWindow):
         rom = self._open_rom(path_to_rom)
 
         *_, powerup, hasPWing = POWERUPS[SETTINGS["default_powerup"]]
+        hasStar = SETTINGS["default_power_has_star"]
 
         rom.write(Title_PrepForWorldMap + 0x1, bytes([powerup]))
 
@@ -653,40 +557,52 @@ class MainWindow(QMainWindow):
         rts = 0x60
         lda = 0xA9
         staAbsolute = 0x8D
+        Map_Power_DispHigh = 0x03
+        Map_Power_DispLow = 0xF3
 
         # If a P-wing powerup is selected, another variable needs to be set with the P-wing value
         # This piece of code overwrites a part of Title_DebugMenu
         if hasPWing:
-            Map_Power_DispHigh = 0x03
-            Map_Power_DispLow = 0xF3
-
             # We need to start one byte before Title_DebugMenu to remove the RTS of Title_PrepForWorldMap
             # The assembly code below reads as follows:
             # LDA 0x08
             # STA $03F3
             # RTS
+            if hasStar:
+                rom.write(
+                    Title_DebugMenu - 0x1,
+                    bytes(
+                        [
+                            lda,
+                            0x08,
+                            staAbsolute,
+                            Map_Power_DispLow,
+                            Map_Power_DispHigh,
+                            lda,
+                            0x10,
+                            staAbsolute,
+                            Map_Power_DispLow - 1,
+                            Map_Power_DispHigh,
+                            rts,
+                        ]
+                    ),
+                )
+            else:
+                rom.write(
+                    Title_DebugMenu - 0x1, bytes([lda, 0x08, staAbsolute, Map_Power_DispLow, Map_Power_DispHigh, rts])
+                )
+
+        elif hasStar:
             rom.write(
-                Title_DebugMenu - 0x1,
-                bytes(
-                    [
-                        lda,
-                        0x8,
-                        staAbsolute,
-                        Map_Power_DispLow,
-                        Map_Power_DispHigh,
-                        # The RTS to get out of the now extended Title_PrepForWorldMap
-                        rts,
-                    ]
-                ),
+                Title_DebugMenu - 0x1, bytes([lda, 0x10, staAbsolute, Map_Power_DispLow - 1, Map_Power_DispHigh, rts])
             )
 
-            # Remove code that resets the powerup value by replacing it with no-operations
-            # Otherwise this code would copy the value of the normal powerup here
-            # (So if the powerup would be Raccoon Mario, Map_Power_Disp would also be
-            # set as Raccoon Mario instead of P-wing
-            Map_Power_DispResetLocation = 0x3C5A2
-            rom.write(Map_Power_DispResetLocation, bytes([nop, nop, nop]))
-
+        # Remove code that resets the powerup value by replacing it with no-operations
+        # Otherwise this code would copy the value of the normal powerup here
+        # (So if the powerup would be Raccoon Mario, Map_Power_Disp would also be
+        # set as Raccoon Mario instead of P-wing
+        Map_Power_DispResetLocation = 0x3C5A2
+        rom.write(Map_Power_DispResetLocation, bytes([nop, nop, nop]))
         rom.save_to(path_to_rom)
         return True
 
@@ -1025,34 +941,10 @@ class MainWindow(QMainWindow):
 
         checked = action.isChecked()
 
-        if item_id == ID_GRID_LINES:
-            self.level_view.draw_grid = checked
-        elif item_id == ID_TRANSPARENCY:
-            self.level_view.transparency = checked
-        elif item_id == ID_JUMPS:
-            self.level_view.draw_jumps = checked
-        elif item_id == ID_MARIO:
-            self.level_view.draw_mario = checked
-        elif item_id == ID_RESIZE_TYPE:
-            self.level_view.draw_expansions = checked
-        elif item_id == ID_JUMP_OBJECTS:
-            self.level_view.draw_jumps_on_objects = checked
-        elif item_id == ID_ITEM_BLOCKS:
-            self.level_view.draw_items_in_blocks = checked
-        elif item_id == ID_INVISIBLE_ITEMS:
-            self.level_view.draw_invisible_items = checked
-        elif item_id == ID_AUTOSCROLL:
-            self.level_view.draw_autoscroll = checked
-
-        SETTINGS["draw_mario"] = self.level_view.draw_mario
-        SETTINGS["draw_jumps"] = self.level_view.draw_jumps
-        SETTINGS["draw_grid"] = self.level_view.draw_grid
-        SETTINGS["draw_expansion"] = self.level_view.draw_expansions
-        SETTINGS["draw_jump_on_objects"] = self.level_view.draw_jumps_on_objects
-        SETTINGS["draw_items_in_blocks"] = self.level_view.draw_items_in_blocks
-        SETTINGS["draw_invisible_items"] = self.level_view.draw_invisible_items
-        SETTINGS["draw_autoscroll"] = self.level_view.draw_autoscroll
-        SETTINGS["block_transparency"] = self.level_view.transparency
+        if item_id not in CHECKABLE_MENU:
+            return
+        setattr(self.level_view, CHECKABLE_MENU[item_id]["attribute"], checked)
+        SETTINGS[CHECKABLE_MENU[item_id]["name"]] = checked
 
         save_settings()
 
