@@ -1,7 +1,7 @@
 import json
 from functools import partial
 
-import qdarkstyle
+import qdarktheme
 
 from foundry import default_settings_path
 
@@ -10,13 +10,14 @@ RESIZE_RIGHT_CLICK = "RMB"
 
 GUI_STYLE = {
     "RETRO": lambda: "",
-    "DRACULA": partial(qdarkstyle.load_stylesheet, pyside=True),
+    "DRACULA": partial(qdarktheme.load_stylesheet),
 }
 
 SETTINGS = dict()
 SETTINGS["instaplay_emulator"] = "fceux"
 SETTINGS["instaplay_arguments"] = "%f"
 SETTINGS["default_powerup"] = 0
+SETTINGS["default_power_has_star"] = False
 
 SETTINGS["resize_mode"] = RESIZE_LEFT_CLICK
 SETTINGS["gui_style"] = ""  # initially blank, since we can't call load_stylesheet until the app is started
